Appearance class

Constructors

Appearance({required String primaryColor, required String captionFontColor, required String captionBackgroundColor, required String logoDestinationUrl, required int fontSize, required int captionFontSize})
Appearance.fromJson(Map<String, dynamic> json)
factory

Properties

captionBackgroundColor String
final
captionFontColor String
final
captionFontSize int
final
fontSize int
final
hashCode int
The hash code for this object.
no setterinherited
final
logoDestinationUrl String
final
primaryColor String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited