Media class

Constructors

Media({required String title, String? description, required String url, List<SubtitleData> subtitles = const [], int startFromSecond = 0, Map<String, String> headers = const {}, String? spriteVttUrl, String? chaptersVttUrl})

Properties

chaptersVttUrl String?
IMA Ads
final
description String?
Video Description (Optional)
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Player headers
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spriteVttUrl String?
IMA Ads
final
startFromSecond int
Where to start media from (in seconds)
final
subtitles List<SubtitleData>
Widevine License URL if the media is DRM protected Fairplay certificate. Can be either URL or Base64 encoded certificate External subtitles url
final
title String
Video Title
final
url String
The Dash URL of the media (required)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited