PlayerConfig class

Configurations - Remote ----------------------------------------------------

Constructors

PlayerConfig({required List<double> playbackSpeeds, required Appearance appearance, required Controls controls, required String organizationId, required String id, required String libraryId, required bool isBetaEnabled, required bool isDefault, required bool enableResumablePosition})
PlayerConfig.fromJson(Map<String, dynamic> json)
factory

Properties

appearance Appearance
final
controls Controls
final
enableResumablePosition bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isBetaEnabled bool
final
isDefault bool
final
libraryId String
final
organizationId String
final
playbackSpeeds List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited