UiControllerMixin mixin

Mixin applications

Properties

configuration Configuration
no setter
controlsVisible ValueNotifier<bool>
final
disposed bool
no setter
hashCode int
The hash code for this object.
no setterinherited
inFullScreen bool
Player is in fullscreen mode or not
getter/setter pair
isMuted bool
no setter
kController → PlayerController
Must be overridden -------------------------------------------------------
no setter
kState → PlayerState
no setter
loading ValueNotifier<bool>
Whether to show loading indicator
final
previewThumbnailController → VideoPreviewThumbnailsController
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spriteImage Image?
no setter
spriteVtt Uint8List?
no setter
volume double
no setter

Methods

autoHideControls() → void
Should be called to reset controls hide trigger. e.g on button click
cancelControlAutoHide() → void
disposeUiControllerMixin() → void
enterFullScreen() → void
exitFullScreen() → void
initializeUiControllerMixin() Future<void>
Must be Called -----------------------------------------------------------
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
setVolume(double value) → void
The volume value should be a double between 0.0 (minimum volume) and 1.0 (maximum volume).
showThumbnailPreview(double progress) → void
toggleBoxFit() → void
toggleMute() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited