VidinfraPlayerController class

Inheritance
Mixed-in types

Constructors

VidinfraPlayerController({Configuration configuration = const Configuration()})

Properties

aesAuthHeaders Map<String, String>
To be automatically passed in as Media headers
getter/setter pairinherited
buffer double
no setter
configuration Configuration
final
controlsVisible ValueNotifier<bool>
finalinherited
disposed bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
inFullScreen bool
Player is in fullscreen mode or not
getter/setter pairinherited
isMuted bool
no setterinherited
kController → PlayerController
Internal implementation, Not to be used outside of the package
latefinal
kState → PlayerState
Internal implementation, Not to be used outside of the package
no setteroverride
loading ValueNotifier<bool>
Whether to show loading indicator
finalinherited
nowPlaying Media?
no setter
playbackSpeed double
no setterinherited
previewThumbnailController → VideoPreviewThumbnailsController
finalinherited
progress double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spriteImage Image?
no setterinherited
spriteVtt Uint8List?
no setterinherited
videoTrack → TrackData?
no setterinherited
videoTracks List<TrackData>
no setterinherited
volume double
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
autoHideControls() → void
Should be called to reset controls hide trigger. e.g on button click
inherited
cancelControlAutoHide() → void
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
disposePlaybackSettingsMixin() → void
inherited
disposeUiControllerMixin() → void
inherited
enterFullScreen() → void
inherited
exitFullScreen() → void
inherited
initializePlaybackSettingsMixin() Future<void>
Must be Called -----------------------------------------------------------
inherited
initializeUiControllerMixin() Future<void>
Must be Called -----------------------------------------------------------
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
play(Media media) Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
seekTo(double value) → void
selectVideoTrack(TrackData? track) → void
inherited
setPlaybackSpeed(double speed) → void
inherited
setupAESAuth({String method = 'GET', required String secret, String referer = "player.vidinfra.com", AESAuthOptions? options}) → void
inherited
setVolume(double value) → void
The volume value should be a double between 0.0 (minimum volume) and 1.0 (maximum volume).
inherited
showThumbnailPreview(double progress) → void
inherited
toggleBoxFit() → void
inherited
toggleMute() Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited