Controls class

Constructors

Controls({bool backward = true, bool forward = true, bool bigPlayButton = true, bool currentTime = true, bool fullscreen = true, bool mute = true, bool pictureInPicture = true, bool playPause = true, bool seekBar = true, bool settings = true, bool branding = true})
const

Properties

backward bool
final
bigPlayButton bool
final
branding bool
final
currentTime bool
final
forward bool
final
fullscreen bool
final
hashCode int
The hash code for this object.
no setterinherited
mute bool
final
pictureInPicture bool
final
playPause bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seekBar bool
final
settings bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited