FullscreenExitAppState class
Constructors
-
FullscreenExitAppState({List<
DeviceOrientation> orientations = const [DeviceOrientation.portraitUp], SystemUiMode mode = SystemUiMode.edgeToEdge}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → SystemUiMode
-
final
-
orientations
→ List<
DeviceOrientation> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited