VidinfraIcons class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

back → const _VidinfraIcon
backward10 → const _VidinfraIcon
backwardSmall → const _VidinfraIcon
brightness → const _VidinfraIcon
checkmark → const _VidinfraIcon
fitScreen → const _VidinfraIcon
forward → const _VidinfraIcon
forward10 → const _VidinfraIcon
forwardSmall → const _VidinfraIcon
pause → const _VidinfraIcon
pip → const _VidinfraIcon
play → const _VidinfraIcon
playbackSpeed → const _VidinfraIcon
quality → const _VidinfraIcon
settings → const _VidinfraIcon
subtitle → const _VidinfraIcon
tenbyte → const _VidinfraIcon
tenbyteSmall → const _VidinfraIcon
volumeHigh → const _VidinfraIcon
volumeLow → const _VidinfraIcon
volumeMid → const _VidinfraIcon
volumeNone → const _VidinfraIcon