Controls class
Constructors
- Controls({required bool backward, required bool forward, required bool cast, required bool bigPlayButton, required bool captions, required bool chapters, required bool currentTime, required bool duration, required bool fullscreen, required bool mute, required bool pictureInPicture, required bool playPause, required bool progress, required bool settings, required bool volume, required bool hideBranding, required bool preload, required bool controlsVisible, required bool enableDownloadButton, required bool loop})
-
Controls.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backward → bool
-
final
- bigPlayButton → bool
-
final
- captions → bool
-
final
- cast → bool
-
final
- chapters → bool
-
final
- controlsVisible → bool
-
final
- currentTime → bool
-
final
- duration → bool
-
final
- enableDownloadButton → bool
-
final
- forward → bool
-
final
- fullscreen → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideBranding → bool
-
final
- loop → bool
-
final
- mute → bool
-
final
- pictureInPicture → bool
-
final
- playPause → bool
-
final
- preload → bool
-
final
- progress → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → bool
-
final
- volume → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited