Configuration class
Constructors
-
Configuration({FullscreenExitAppState fullscreenExitAppState = const FullscreenExitAppState(), List<
double> playbackSpeeds = const [0.5, 1.0, 1.5, 2], Controls controls = const Controls()}) -
const
Properties
- controls → Controls
-
final
- fullscreenExitAppState → FullscreenExitAppState
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
playbackSpeeds
→ List<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited